Summary: The GNU Bourne Again shell
Name: bash
Version: 5.2.15
Release: 4%{?dist}
License: GPLv3+
Url: https://www.gnu.org/software/bash
Source0: https://ftp.gnu.org/gnu/bash/bash-%{version}.tar.gz
Source1: dot-bashrc
Source2: dot-bash_profile
Source3: dot-bash_logout

Patch1: 0001-add-NON_INTERACTIVE_LOGIN_SHELLS-config-to-run-the-l.patch
BuildRequires: gcc autoconf make texinfo bison ncurses-devel
# Required for bash tests
BuildRequires: glibc-all-langpacks
Requires: filesystem >= 3
Provides: /bin/sh /bin/bash

%description
Bash is the GNU Project's shell—the Bourne Again SHell. This is an sh-compatible 
shell that incorporates useful features from the Korn shell (ksh) and the C shell 
(csh). It is intended to conform to the IEEE POSIX P1003.2/ISO 9945.2 Shell and 
Tools standard. It offers functional improvements over sh for both programming and
interactive use. In addition, most sh scripts can be run by Bash without modification.


%package devel
Summary: Development headers for bash
Requires: %{name} = %{version}-%{release}

%description devel
This package contains development headers for bash.


%package doc
Summary: Documentation files of bash
Requires: %{name} = %{version}-%{release}

%description doc
This package contains documentation files of bash.


%prep
%autosetup -n %{name}-%{version} -p1
rm y.tab.*


%build
autoconf
# to dynamic define RECYCLES_PIDS, DEFAULT_PATH_VALUE in bash when build it.
CPPFLAGS="${CPPFLAGS} -fcommon -DRECYCLES_PIDS -DDEFAULT_PATH_VALUE='\"/usr/local/bin:/usr/bin\"' `getconf LFS_CFLAGS`";export CPPFLAGS;
%configure --with-bash-malloc=no --with-afs
# update version.h and build bash builtins and bash
make version.h
make %{?_smp_mflags} -C builtins
make %{?_smp_mflags}


%install
%make_install install-headers
mkdir -p %{buildroot}/%{_sysconfdir}
# install manpages for bash builtins
pushd doc
install -p -m 644 builtins.1 %{buildroot}%{_mandir}/man1/builtins.1
popd
ln -s bash.1 %{buildroot}%{_mandir}/man1/sh.1
ln -sf bash %{buildroot}%{_bindir}/sh
# install configure files
%find_lang %{name}
mkdir -p %{buildroot}%{_sysconfdir}/skel
install -p -m644 %SOURCE1 %{buildroot}/etc/skel/.bashrc
install -p -m644 %SOURCE2 %{buildroot}/etc/skel/.bash_profile
install -p -m644 %SOURCE3 %{buildroot}/etc/skel/.bash_logout
rm -f %{buildroot}%{_infodir}/dir


%check
make check


%post -p <lua>
--When bash installed,check file /etc/shells ,assure '/bin/sh' and '/bin/bash' be writed in.
local filename = "/etc/shells"
local sh_found = 0
local bash_found = 0
local sh = "/bin/sh"
local bash ="/bin/bash"
for line in io.lines(filename)
do
  if bash_found == 0 and line == bash then 
    bash_found = 1
  elseif sh_found == 0 and  line == sh then
    sh_found = 1
  elseif bash_found == 1 and sh_found == 1 then
    break
  end
end
local f = io.open(filename, "a+")
if sh_found == 0 then f:write(sh.."\n")  end
if bash_found == 0 then f:write(bash.."\n") end
f:flush()
f:close()


%postun -p <lua>
-- delete /bin/sh and /bin/bash from /etc/shells if we are uninstalling (arg[2]=0).
if arg[2] == 0  then
  local filename = "/etc/shells"
  local buffer = ""
  for line in io.lines(filename)
  do
    if line ~= "/bin/sh" and line ~= "/bin/bash"  then
        buffer = buffer..line.."\n"
    end
  end
  f = io.open(filename,"w+")
  f:write(buffer)
  f:flush()
  f:close()
end


%files -f %{name}.lang
%license COPYING
%doc RBASH README
%doc doc/{FAQ,INTRO,README,bash{,ref}.html}
%dir %{_docdir}/%{name}
%{_infodir}/*
%{_mandir}/*/*
%config(noreplace) /etc/skel/.b*
%{_bindir}/sh
%{_bindir}/bash
%{_bindir}/bashbug


%files doc
%{_docdir}/%{name}/*
%doc doc/*.ps doc/*.0 doc/*.html doc/article.txt


%files devel
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/bash/*


%changelog
* Wed May 29 2024 Pengda Dou <doupengda@loongson.cn> - 5.2.15-4
- [Type] bugfix
- [DESC] Fix file dir duplication problem

* Wed May 22 2024 Doris Chao <doriscchao@tencent.com> - 5.2.15-3
- [Type] other
- [DESC] Define NON_INTERACTIVE_LOGIN_SHELLS config to run the
- login shell startup files if argv[0][0] == '-'

* Tue Jan 16 2024 Doris Chao <doriscchao@tencent.com> - 5.2.15-2
- Rebuild for the untested version 5.2.15-1

* Mon Jan 15 2024 Doris Chao <doriscchao@tencent.com> - 5.2.15-1
- Upgrade to bash 5.2.15

* Thu Nov 16 2023 Xiaojie Chen <jackxjchen@tencent.com> - 5.2-3
- fix crash with unset arrays in arithmetic contexts
- fix crash in readline when started with an invalid locale specification

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.2-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 03 2023 kianli <kianli@tencent.com> - 5.2-1
- Upgrade to 5.2 and fix bogus date in changelog

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.1.16-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 5.1.16-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Apr 20 2022 doriscchao <doriscchao@tencent.com> - 5.1.16-1
- initial build, Version 5.1.16, Release 1

